@@ -5,9 +5,9 @@
 @Author: Wang Yao
 @Date: 2020-03-13 13:53:26
 @LastEditors: Wang Yao
-@LastEditTime: 2020-03-13 16:30:07
+@LastEditTime: 2020-03-15 18:16:50
 '''
 from .loader import *
-from .paddle_to_tensor import *
+from .convert import *
 
-__version__ = '1.0.4'
\ No newline at end of file
+__version__ = '1.0.5'
\ No newline at end of file
